@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Text, Union
+from typing import Text
 
 from neuralspace.nlu.converters.base import DataConverter
 
@@ -8,9 +8,7 @@ class DialogflowConverter(DataConverter):
         super().__init__(language=language)
 
     @staticmethod
-    def training_data_converter(
-        final_data
-    ):
+    def training_data_converter(final_data):
         """
         :type final_data: Dictionary of object that contains all the NLU data.
         """
@@ -19,9 +17,7 @@ class DialogflowConverter(DataConverter):
             list_of_examples.append(value)
         return list_of_examples
 
-    def regex_converter(
-        self, final_data
-    ):
+    def regex_converter(self, final_data):
         """
         :type final_data: Dictionary of object that contains all the NLU data.
         """
@@ -42,9 +38,7 @@ class DialogflowConverter(DataConverter):
             regex_entity[index]["examples"].append(value["pattern"])
         return regex_entity
 
-    def lookup_converter(
-        self, final_data
-    ):
+    def lookup_converter(self, final_data):
         """
         :type final_data: Dictionary of object that contains all the NLU data.
         """
@@ -58,9 +52,7 @@ class DialogflowConverter(DataConverter):
 
         return list_of_lookup
 
-    def synonym_converter(
-        self, final_data
-    ):
+    def synonym_converter(self, final_data):
         """
         :type final_data: Dictionary of object that contains all the NLU data.
         """
