@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Text, Union
+from typing import Text
 
 from rasa.shared.nlu.training_data.training_data import TrainingData
 
@@ -9,9 +9,7 @@ class RasaConverter(DataConverter):
     def __init__(self, language: Text):
         super().__init__(language=language)
 
-    def lookup_converter(
-        self, final_data
-    ):
+    def lookup_converter(self, final_data):
         list_of_lookups = []
         for value in final_data:
             value["entity"] = value.pop("name")
@@ -21,9 +19,7 @@ class RasaConverter(DataConverter):
             list_of_lookups.append(value)
         return list_of_lookups
 
-    def regex_converter(
-        self, final_data
-    ):
+    def regex_converter(self, final_data):
         """
         :param language: To specify which language that the entity belongs
         :type final_data: Dictionary of object that contains all the NLU data.
@@ -43,9 +39,7 @@ class RasaConverter(DataConverter):
                 list_of_regex[index]["examples"].append(value["pattern"])
         return list_of_regex
 
-    def synonym_converter(
-        self, final_data
-    ):
+    def synonym_converter(self, final_data):
         """
         :param language: To specify which language that the entity belongs
         :type final_data: Dictionary of object that contains all the NLU data.
@@ -71,7 +65,7 @@ class RasaConverter(DataConverter):
     @staticmethod
     def training_data_converter(
         final_data: TrainingData,
-    ) -> List[Union[Text, Dict[Text]]]:
+    ):
         """
         :type final_data: Dictionary of object that contains all the NLU data.
         """
